# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ImageDetails(object):
    """
    Image details containing the subscribed image, its status, version, owner and time of creation.
    """

    #: A constant which can be used with the image_status property of a ImageDetails.
    #: This constant has a value of "GREEN"
    IMAGE_STATUS_GREEN = "GREEN"

    #: A constant which can be used with the image_status property of a ImageDetails.
    #: This constant has a value of "YELLOW"
    IMAGE_STATUS_YELLOW = "YELLOW"

    #: A constant which can be used with the image_status property of a ImageDetails.
    #: This constant has a value of "RED"
    IMAGE_STATUS_RED = "RED"

    def __init__(self, **kwargs):
        """
        Initializes a new ImageDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param image_id:
            The value to assign to the image_id property of this ImageDetails.
        :type image_id: str

        :param subscribed_image:
            The value to assign to the subscribed_image property of this ImageDetails.
        :type subscribed_image: str

        :param current_version:
            The value to assign to the current_version property of this ImageDetails.
        :type current_version: str

        :param image_status:
            The value to assign to the image_status property of this ImageDetails.
            Allowed values for this property are: "GREEN", "YELLOW", "RED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type image_status: str

        :param image_version:
            The value to assign to the image_version property of this ImageDetails.
        :type image_version: str

        :param image_owner:
            The value to assign to the image_owner property of this ImageDetails.
        :type image_owner: str

        :param created_by:
            The value to assign to the created_by property of this ImageDetails.
        :type created_by: str

        :param time_image_creation:
            The value to assign to the time_image_creation property of this ImageDetails.
        :type time_image_creation: datetime

        :param up_to_date_image_version:
            The value to assign to the up_to_date_image_version property of this ImageDetails.
        :type up_to_date_image_version: str

        """
        self.swagger_types = {
            'image_id': 'str',
            'subscribed_image': 'str',
            'current_version': 'str',
            'image_status': 'str',
            'image_version': 'str',
            'image_owner': 'str',
            'created_by': 'str',
            'time_image_creation': 'datetime',
            'up_to_date_image_version': 'str'
        }
        self.attribute_map = {
            'image_id': 'imageId',
            'subscribed_image': 'subscribedImage',
            'current_version': 'currentVersion',
            'image_status': 'imageStatus',
            'image_version': 'imageVersion',
            'image_owner': 'imageOwner',
            'created_by': 'createdBy',
            'time_image_creation': 'timeImageCreation',
            'up_to_date_image_version': 'upToDateImageVersion'
        }
        self._image_id = None
        self._subscribed_image = None
        self._current_version = None
        self._image_status = None
        self._image_version = None
        self._image_owner = None
        self._created_by = None
        self._time_image_creation = None
        self._up_to_date_image_version = None

    @property
    def image_id(self):
        """
        Gets the image_id of this ImageDetails.
        Image identifier.


        :return: The image_id of this ImageDetails.
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id):
        """
        Sets the image_id of this ImageDetails.
        Image identifier.


        :param image_id: The image_id of this ImageDetails.
        :type: str
        """
        self._image_id = image_id

    @property
    def subscribed_image(self):
        """
        Gets the subscribed_image of this ImageDetails.
        Subscribed image.


        :return: The subscribed_image of this ImageDetails.
        :rtype: str
        """
        return self._subscribed_image

    @subscribed_image.setter
    def subscribed_image(self, subscribed_image):
        """
        Sets the subscribed_image of this ImageDetails.
        Subscribed image.


        :param subscribed_image: The subscribed_image of this ImageDetails.
        :type: str
        """
        self._subscribed_image = subscribed_image

    @property
    def current_version(self):
        """
        Gets the current_version of this ImageDetails.
        Name of the image version marked as current of the image.


        :return: The current_version of this ImageDetails.
        :rtype: str
        """
        return self._current_version

    @current_version.setter
    def current_version(self, current_version):
        """
        Sets the current_version of this ImageDetails.
        Name of the image version marked as current of the image.


        :param current_version: The current_version of this ImageDetails.
        :type: str
        """
        self._current_version = current_version

    @property
    def image_status(self):
        """
        Gets the image_status of this ImageDetails.
        Image status.

        Allowed values for this property are: "GREEN", "YELLOW", "RED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The image_status of this ImageDetails.
        :rtype: str
        """
        return self._image_status

    @image_status.setter
    def image_status(self, image_status):
        """
        Sets the image_status of this ImageDetails.
        Image status.


        :param image_status: The image_status of this ImageDetails.
        :type: str
        """
        allowed_values = ["GREEN", "YELLOW", "RED"]
        if not value_allowed_none_or_none_sentinel(image_status, allowed_values):
            image_status = 'UNKNOWN_ENUM_VALUE'
        self._image_status = image_status

    @property
    def image_version(self):
        """
        Gets the image_version of this ImageDetails.
        Release version of the image.


        :return: The image_version of this ImageDetails.
        :rtype: str
        """
        return self._image_version

    @image_version.setter
    def image_version(self, image_version):
        """
        Sets the image_version of this ImageDetails.
        Release version of the image.


        :param image_version: The image_version of this ImageDetails.
        :type: str
        """
        self._image_version = image_version

    @property
    def image_owner(self):
        """
        Gets the image_owner of this ImageDetails.
        Owner of the image.


        :return: The image_owner of this ImageDetails.
        :rtype: str
        """
        return self._image_owner

    @image_owner.setter
    def image_owner(self, image_owner):
        """
        Sets the image_owner of this ImageDetails.
        Owner of the image.


        :param image_owner: The image_owner of this ImageDetails.
        :type: str
        """
        self._image_owner = image_owner

    @property
    def created_by(self):
        """
        Gets the created_by of this ImageDetails.
        Name of the person who created the image.


        :return: The created_by of this ImageDetails.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this ImageDetails.
        Name of the person who created the image.


        :param created_by: The created_by of this ImageDetails.
        :type: str
        """
        self._created_by = created_by

    @property
    def time_image_creation(self):
        """
        Gets the time_image_creation of this ImageDetails.
        Date when the image was created.


        :return: The time_image_creation of this ImageDetails.
        :rtype: datetime
        """
        return self._time_image_creation

    @time_image_creation.setter
    def time_image_creation(self, time_image_creation):
        """
        Sets the time_image_creation of this ImageDetails.
        Date when the image was created.


        :param time_image_creation: The time_image_creation of this ImageDetails.
        :type: datetime
        """
        self._time_image_creation = time_image_creation

    @property
    def up_to_date_image_version(self):
        """
        Gets the up_to_date_image_version of this ImageDetails.
        An image version name, that is up to date and has no recommendations.


        :return: The up_to_date_image_version of this ImageDetails.
        :rtype: str
        """
        return self._up_to_date_image_version

    @up_to_date_image_version.setter
    def up_to_date_image_version(self, up_to_date_image_version):
        """
        Sets the up_to_date_image_version of this ImageDetails.
        An image version name, that is up to date and has no recommendations.


        :param up_to_date_image_version: The up_to_date_image_version of this ImageDetails.
        :type: str
        """
        self._up_to_date_image_version = up_to_date_image_version

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PatchOperationsSummary(object):
    """
    Patch operation list summary by status record.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PatchOperationsSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param scheduled_patch_ops_count:
            The value to assign to the scheduled_patch_ops_count property of this PatchOperationsSummary.
        :type scheduled_patch_ops_count: int

        :param running_patch_ops_count:
            The value to assign to the running_patch_ops_count property of this PatchOperationsSummary.
        :type running_patch_ops_count: int

        :param successful_patch_ops_count:
            The value to assign to the successful_patch_ops_count property of this PatchOperationsSummary.
        :type successful_patch_ops_count: int

        :param warnings_patch_ops_count:
            The value to assign to the warnings_patch_ops_count property of this PatchOperationsSummary.
        :type warnings_patch_ops_count: int

        :param failed_patch_ops_count:
            The value to assign to the failed_patch_ops_count property of this PatchOperationsSummary.
        :type failed_patch_ops_count: int

        """
        self.swagger_types = {
            'scheduled_patch_ops_count': 'int',
            'running_patch_ops_count': 'int',
            'successful_patch_ops_count': 'int',
            'warnings_patch_ops_count': 'int',
            'failed_patch_ops_count': 'int'
        }
        self.attribute_map = {
            'scheduled_patch_ops_count': 'scheduledPatchOpsCount',
            'running_patch_ops_count': 'runningPatchOpsCount',
            'successful_patch_ops_count': 'successfulPatchOpsCount',
            'warnings_patch_ops_count': 'warningsPatchOpsCount',
            'failed_patch_ops_count': 'failedPatchOpsCount'
        }
        self._scheduled_patch_ops_count = None
        self._running_patch_ops_count = None
        self._successful_patch_ops_count = None
        self._warnings_patch_ops_count = None
        self._failed_patch_ops_count = None

    @property
    def scheduled_patch_ops_count(self):
        """
        Gets the scheduled_patch_ops_count of this PatchOperationsSummary.
        Total number of scheduled Patch operations.


        :return: The scheduled_patch_ops_count of this PatchOperationsSummary.
        :rtype: int
        """
        return self._scheduled_patch_ops_count

    @scheduled_patch_ops_count.setter
    def scheduled_patch_ops_count(self, scheduled_patch_ops_count):
        """
        Sets the scheduled_patch_ops_count of this PatchOperationsSummary.
        Total number of scheduled Patch operations.


        :param scheduled_patch_ops_count: The scheduled_patch_ops_count of this PatchOperationsSummary.
        :type: int
        """
        self._scheduled_patch_ops_count = scheduled_patch_ops_count

    @property
    def running_patch_ops_count(self):
        """
        Gets the running_patch_ops_count of this PatchOperationsSummary.
        Total number of in progress Patch operations.


        :return: The running_patch_ops_count of this PatchOperationsSummary.
        :rtype: int
        """
        return self._running_patch_ops_count

    @running_patch_ops_count.setter
    def running_patch_ops_count(self, running_patch_ops_count):
        """
        Sets the running_patch_ops_count of this PatchOperationsSummary.
        Total number of in progress Patch operations.


        :param running_patch_ops_count: The running_patch_ops_count of this PatchOperationsSummary.
        :type: int
        """
        self._running_patch_ops_count = running_patch_ops_count

    @property
    def successful_patch_ops_count(self):
        """
        Gets the successful_patch_ops_count of this PatchOperationsSummary.
        Total number of successful Patch operations.


        :return: The successful_patch_ops_count of this PatchOperationsSummary.
        :rtype: int
        """
        return self._successful_patch_ops_count

    @successful_patch_ops_count.setter
    def successful_patch_ops_count(self, successful_patch_ops_count):
        """
        Sets the successful_patch_ops_count of this PatchOperationsSummary.
        Total number of successful Patch operations.


        :param successful_patch_ops_count: The successful_patch_ops_count of this PatchOperationsSummary.
        :type: int
        """
        self._successful_patch_ops_count = successful_patch_ops_count

    @property
    def warnings_patch_ops_count(self):
        """
        Gets the warnings_patch_ops_count of this PatchOperationsSummary.
        Total number of Patch operations that have warnings.


        :return: The warnings_patch_ops_count of this PatchOperationsSummary.
        :rtype: int
        """
        return self._warnings_patch_ops_count

    @warnings_patch_ops_count.setter
    def warnings_patch_ops_count(self, warnings_patch_ops_count):
        """
        Sets the warnings_patch_ops_count of this PatchOperationsSummary.
        Total number of Patch operations that have warnings.


        :param warnings_patch_ops_count: The warnings_patch_ops_count of this PatchOperationsSummary.
        :type: int
        """
        self._warnings_patch_ops_count = warnings_patch_ops_count

    @property
    def failed_patch_ops_count(self):
        """
        Gets the failed_patch_ops_count of this PatchOperationsSummary.
        Total number of failed Patch operations.


        :return: The failed_patch_ops_count of this PatchOperationsSummary.
        :rtype: int
        """
        return self._failed_patch_ops_count

    @failed_patch_ops_count.setter
    def failed_patch_ops_count(self, failed_patch_ops_count):
        """
        Sets the failed_patch_ops_count of this PatchOperationsSummary.
        Total number of failed Patch operations.


        :param failed_patch_ops_count: The failed_patch_ops_count of this PatchOperationsSummary.
        :type: int
        """
        self._failed_patch_ops_count = failed_patch_ops_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ChildPdb(object):
    """
    Child PDB for a CDB.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ChildPdb object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param pdb_id:
            The value to assign to the pdb_id property of this ChildPdb.
        :type pdb_id: str

        :param name:
            The value to assign to the name property of this ChildPdb.
        :type name: str

        :param open_mode:
            The value to assign to the open_mode property of this ChildPdb.
        :type open_mode: str

        :param restricted:
            The value to assign to the restricted property of this ChildPdb.
        :type restricted: str

        :param recovery_status:
            The value to assign to the recovery_status property of this ChildPdb.
        :type recovery_status: str

        :param last_changed_by:
            The value to assign to the last_changed_by property of this ChildPdb.
        :type last_changed_by: str

        """
        self.swagger_types = {
            'pdb_id': 'str',
            'name': 'str',
            'open_mode': 'str',
            'restricted': 'str',
            'recovery_status': 'str',
            'last_changed_by': 'str'
        }
        self.attribute_map = {
            'pdb_id': 'pdbId',
            'name': 'name',
            'open_mode': 'openMode',
            'restricted': 'restricted',
            'recovery_status': 'recoveryStatus',
            'last_changed_by': 'lastChangedBy'
        }
        self._pdb_id = None
        self._name = None
        self._open_mode = None
        self._restricted = None
        self._recovery_status = None
        self._last_changed_by = None

    @property
    def pdb_id(self):
        """
        **[Required]** Gets the pdb_id of this ChildPdb.
        Identifier for the pluggable database.


        :return: The pdb_id of this ChildPdb.
        :rtype: str
        """
        return self._pdb_id

    @pdb_id.setter
    def pdb_id(self, pdb_id):
        """
        Sets the pdb_id of this ChildPdb.
        Identifier for the pluggable database.


        :param pdb_id: The pdb_id of this ChildPdb.
        :type: str
        """
        self._pdb_id = pdb_id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this ChildPdb.
        Name fo the pluggable database.


        :return: The name of this ChildPdb.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ChildPdb.
        Name fo the pluggable database.


        :param name: The name of this ChildPdb.
        :type: str
        """
        self._name = name

    @property
    def open_mode(self):
        """
        **[Required]** Gets the open_mode of this ChildPdb.
        Open mode


        :return: The open_mode of this ChildPdb.
        :rtype: str
        """
        return self._open_mode

    @open_mode.setter
    def open_mode(self, open_mode):
        """
        Sets the open_mode of this ChildPdb.
        Open mode


        :param open_mode: The open_mode of this ChildPdb.
        :type: str
        """
        self._open_mode = open_mode

    @property
    def restricted(self):
        """
        **[Required]** Gets the restricted of this ChildPdb.
        Restricted


        :return: The restricted of this ChildPdb.
        :rtype: str
        """
        return self._restricted

    @restricted.setter
    def restricted(self, restricted):
        """
        Sets the restricted of this ChildPdb.
        Restricted


        :param restricted: The restricted of this ChildPdb.
        :type: str
        """
        self._restricted = restricted

    @property
    def recovery_status(self):
        """
        **[Required]** Gets the recovery_status of this ChildPdb.
        Recovery status


        :return: The recovery_status of this ChildPdb.
        :rtype: str
        """
        return self._recovery_status

    @recovery_status.setter
    def recovery_status(self, recovery_status):
        """
        Sets the recovery_status of this ChildPdb.
        Recovery status


        :param recovery_status: The recovery_status of this ChildPdb.
        :type: str
        """
        self._recovery_status = recovery_status

    @property
    def last_changed_by(self):
        """
        **[Required]** Gets the last_changed_by of this ChildPdb.
        Last changed by


        :return: The last_changed_by of this ChildPdb.
        :rtype: str
        """
        return self._last_changed_by

    @last_changed_by.setter
    def last_changed_by(self, last_changed_by):
        """
        Sets the last_changed_by of this ChildPdb.
        Last changed by


        :param last_changed_by: The last_changed_by of this ChildPdb.
        :type: str
        """
        self._last_changed_by = last_changed_by

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PatchComplianceDetails(object):
    """
    Patch Compliance Status
    """

    #: A constant which can be used with the patch_compliance_status property of a PatchComplianceDetails.
    #: This constant has a value of "GREEN"
    PATCH_COMPLIANCE_STATUS_GREEN = "GREEN"

    #: A constant which can be used with the patch_compliance_status property of a PatchComplianceDetails.
    #: This constant has a value of "YELLOW"
    PATCH_COMPLIANCE_STATUS_YELLOW = "YELLOW"

    #: A constant which can be used with the patch_compliance_status property of a PatchComplianceDetails.
    #: This constant has a value of "RED"
    PATCH_COMPLIANCE_STATUS_RED = "RED"

    def __init__(self, **kwargs):
        """
        Initializes a new PatchComplianceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param patch_compliance_status:
            The value to assign to the patch_compliance_status property of this PatchComplianceDetails.
            Allowed values for this property are: "GREEN", "YELLOW", "RED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type patch_compliance_status: str

        :param patch_compliance_version:
            The value to assign to the patch_compliance_version property of this PatchComplianceDetails.
        :type patch_compliance_version: str

        """
        self.swagger_types = {
            'patch_compliance_status': 'str',
            'patch_compliance_version': 'str'
        }
        self.attribute_map = {
            'patch_compliance_status': 'patchComplianceStatus',
            'patch_compliance_version': 'patchComplianceVersion'
        }
        self._patch_compliance_status = None
        self._patch_compliance_version = None

    @property
    def patch_compliance_status(self):
        """
        Gets the patch_compliance_status of this PatchComplianceDetails.
        Patch compliance status.

        Allowed values for this property are: "GREEN", "YELLOW", "RED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The patch_compliance_status of this PatchComplianceDetails.
        :rtype: str
        """
        return self._patch_compliance_status

    @patch_compliance_status.setter
    def patch_compliance_status(self, patch_compliance_status):
        """
        Sets the patch_compliance_status of this PatchComplianceDetails.
        Patch compliance status.


        :param patch_compliance_status: The patch_compliance_status of this PatchComplianceDetails.
        :type: str
        """
        allowed_values = ["GREEN", "YELLOW", "RED"]
        if not value_allowed_none_or_none_sentinel(patch_compliance_status, allowed_values):
            patch_compliance_status = 'UNKNOWN_ENUM_VALUE'
        self._patch_compliance_status = patch_compliance_status

    @property
    def patch_compliance_version(self):
        """
        Gets the patch_compliance_version of this PatchComplianceDetails.
        Resource patch compliance version name.


        :return: The patch_compliance_version of this PatchComplianceDetails.
        :rtype: str
        """
        return self._patch_compliance_version

    @patch_compliance_version.setter
    def patch_compliance_version(self, patch_compliance_version):
        """
        Sets the patch_compliance_version of this PatchComplianceDetails.
        Resource patch compliance version name.


        :param patch_compliance_version: The patch_compliance_version of this PatchComplianceDetails.
        :type: str
        """
        self._patch_compliance_version = patch_compliance_version

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ImagesPatchRecommendationSummary(object):
    """
    Summary of image patches recommended to install.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ImagesPatchRecommendationSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param total_images_count:
            The value to assign to the total_images_count property of this ImagesPatchRecommendationSummary.
        :type total_images_count: int

        :param up_to_date_images_count:
            The value to assign to the up_to_date_images_count property of this ImagesPatchRecommendationSummary.
        :type up_to_date_images_count: int

        :param image_patch_recommendations_count:
            The value to assign to the image_patch_recommendations_count property of this ImagesPatchRecommendationSummary.
        :type image_patch_recommendations_count: int

        """
        self.swagger_types = {
            'total_images_count': 'int',
            'up_to_date_images_count': 'int',
            'image_patch_recommendations_count': 'int'
        }
        self.attribute_map = {
            'total_images_count': 'totalImagesCount',
            'up_to_date_images_count': 'upToDateImagesCount',
            'image_patch_recommendations_count': 'imagePatchRecommendationsCount'
        }
        self._total_images_count = None
        self._up_to_date_images_count = None
        self._image_patch_recommendations_count = None

    @property
    def total_images_count(self):
        """
        Gets the total_images_count of this ImagesPatchRecommendationSummary.
        Total number of images.


        :return: The total_images_count of this ImagesPatchRecommendationSummary.
        :rtype: int
        """
        return self._total_images_count

    @total_images_count.setter
    def total_images_count(self, total_images_count):
        """
        Sets the total_images_count of this ImagesPatchRecommendationSummary.
        Total number of images.


        :param total_images_count: The total_images_count of this ImagesPatchRecommendationSummary.
        :type: int
        """
        self._total_images_count = total_images_count

    @property
    def up_to_date_images_count(self):
        """
        Gets the up_to_date_images_count of this ImagesPatchRecommendationSummary.
        Total number of up to date images.


        :return: The up_to_date_images_count of this ImagesPatchRecommendationSummary.
        :rtype: int
        """
        return self._up_to_date_images_count

    @up_to_date_images_count.setter
    def up_to_date_images_count(self, up_to_date_images_count):
        """
        Sets the up_to_date_images_count of this ImagesPatchRecommendationSummary.
        Total number of up to date images.


        :param up_to_date_images_count: The up_to_date_images_count of this ImagesPatchRecommendationSummary.
        :type: int
        """
        self._up_to_date_images_count = up_to_date_images_count

    @property
    def image_patch_recommendations_count(self):
        """
        Gets the image_patch_recommendations_count of this ImagesPatchRecommendationSummary.
        Total number of patch recommendations available.


        :return: The image_patch_recommendations_count of this ImagesPatchRecommendationSummary.
        :rtype: int
        """
        return self._image_patch_recommendations_count

    @image_patch_recommendations_count.setter
    def image_patch_recommendations_count(self, image_patch_recommendations_count):
        """
        Sets the image_patch_recommendations_count of this ImagesPatchRecommendationSummary.
        Total number of patch recommendations available.


        :param image_patch_recommendations_count: The image_patch_recommendations_count of this ImagesPatchRecommendationSummary.
        :type: int
        """
        self._image_patch_recommendations_count = image_patch_recommendations_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FppServer(object):
    """
    Description of FPP Server.
    """

    #: A constant which can be used with the lifecycle_state property of a FppServer.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a FppServer.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a FppServer.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a FppServer.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a FppServer.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a FppServer.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new FppServer object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this FppServer.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this FppServer.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this FppServer.
        :type compartment_id: str

        :param management_agent_id:
            The value to assign to the management_agent_id property of this FppServer.
        :type management_agent_id: str

        :param mac_agent_compartment_id:
            The value to assign to the mac_agent_compartment_id property of this FppServer.
        :type mac_agent_compartment_id: str

        :param fpp_rest_url:
            The value to assign to the fpp_rest_url property of this FppServer.
        :type fpp_rest_url: str

        :param trust_store_location:
            The value to assign to the trust_store_location property of this FppServer.
        :type trust_store_location: str

        :param trust_store_password:
            The value to assign to the trust_store_password property of this FppServer.
        :type trust_store_password: str

        :param rest_user_name:
            The value to assign to the rest_user_name property of this FppServer.
        :type rest_user_name: str

        :param rest_user_password:
            The value to assign to the rest_user_password property of this FppServer.
        :type rest_user_password: str

        :param time_created:
            The value to assign to the time_created property of this FppServer.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this FppServer.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this FppServer.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this FppServer.
        :type lifecycle_details: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this FppServer.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this FppServer.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this FppServer.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'compartment_id': 'str',
            'management_agent_id': 'str',
            'mac_agent_compartment_id': 'str',
            'fpp_rest_url': 'str',
            'trust_store_location': 'str',
            'trust_store_password': 'str',
            'rest_user_name': 'str',
            'rest_user_password': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }
        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'management_agent_id': 'managementAgentId',
            'mac_agent_compartment_id': 'macAgentCompartmentId',
            'fpp_rest_url': 'fppRestUrl',
            'trust_store_location': 'trustStoreLocation',
            'trust_store_password': 'trustStorePassword',
            'rest_user_name': 'restUserName',
            'rest_user_password': 'restUserPassword',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }
        self._id = None
        self._display_name = None
        self._compartment_id = None
        self._management_agent_id = None
        self._mac_agent_compartment_id = None
        self._fpp_rest_url = None
        self._trust_store_location = None
        self._trust_store_password = None
        self._rest_user_name = None
        self._rest_user_password = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this FppServer.
        Unique identifier that is immutable on creation


        :return: The id of this FppServer.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this FppServer.
        Unique identifier that is immutable on creation


        :param id: The id of this FppServer.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this FppServer.
        FPP Server Identifier, can be renamed


        :return: The display_name of this FppServer.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this FppServer.
        FPP Server Identifier, can be renamed


        :param display_name: The display_name of this FppServer.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this FppServer.
        Compartment Identifier


        :return: The compartment_id of this FppServer.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this FppServer.
        Compartment Identifier


        :param compartment_id: The compartment_id of this FppServer.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def management_agent_id(self):
        """
        Gets the management_agent_id of this FppServer.
        Unique Management Agent identifier


        :return: The management_agent_id of this FppServer.
        :rtype: str
        """
        return self._management_agent_id

    @management_agent_id.setter
    def management_agent_id(self, management_agent_id):
        """
        Sets the management_agent_id of this FppServer.
        Unique Management Agent identifier


        :param management_agent_id: The management_agent_id of this FppServer.
        :type: str
        """
        self._management_agent_id = management_agent_id

    @property
    def mac_agent_compartment_id(self):
        """
        Gets the mac_agent_compartment_id of this FppServer.
        Unique Management Agent Compartment identifier


        :return: The mac_agent_compartment_id of this FppServer.
        :rtype: str
        """
        return self._mac_agent_compartment_id

    @mac_agent_compartment_id.setter
    def mac_agent_compartment_id(self, mac_agent_compartment_id):
        """
        Sets the mac_agent_compartment_id of this FppServer.
        Unique Management Agent Compartment identifier


        :param mac_agent_compartment_id: The mac_agent_compartment_id of this FppServer.
        :type: str
        """
        self._mac_agent_compartment_id = mac_agent_compartment_id

    @property
    def fpp_rest_url(self):
        """
        Gets the fpp_rest_url of this FppServer.
        REST endpoint URL of FPP Server


        :return: The fpp_rest_url of this FppServer.
        :rtype: str
        """
        return self._fpp_rest_url

    @fpp_rest_url.setter
    def fpp_rest_url(self, fpp_rest_url):
        """
        Sets the fpp_rest_url of this FppServer.
        REST endpoint URL of FPP Server


        :param fpp_rest_url: The fpp_rest_url of this FppServer.
        :type: str
        """
        self._fpp_rest_url = fpp_rest_url

    @property
    def trust_store_location(self):
        """
        Gets the trust_store_location of this FppServer.
        Absolute path of JKS Trust Store


        :return: The trust_store_location of this FppServer.
        :rtype: str
        """
        return self._trust_store_location

    @trust_store_location.setter
    def trust_store_location(self, trust_store_location):
        """
        Sets the trust_store_location of this FppServer.
        Absolute path of JKS Trust Store


        :param trust_store_location: The trust_store_location of this FppServer.
        :type: str
        """
        self._trust_store_location = trust_store_location

    @property
    def trust_store_password(self):
        """
        Gets the trust_store_password of this FppServer.
        JKS Trust Store Password


        :return: The trust_store_password of this FppServer.
        :rtype: str
        """
        return self._trust_store_password

    @trust_store_password.setter
    def trust_store_password(self, trust_store_password):
        """
        Sets the trust_store_password of this FppServer.
        JKS Trust Store Password


        :param trust_store_password: The trust_store_password of this FppServer.
        :type: str
        """
        self._trust_store_password = trust_store_password

    @property
    def rest_user_name(self):
        """
        Gets the rest_user_name of this FppServer.
        FPP REST User Name


        :return: The rest_user_name of this FppServer.
        :rtype: str
        """
        return self._rest_user_name

    @rest_user_name.setter
    def rest_user_name(self, rest_user_name):
        """
        Sets the rest_user_name of this FppServer.
        FPP REST User Name


        :param rest_user_name: The rest_user_name of this FppServer.
        :type: str
        """
        self._rest_user_name = rest_user_name

    @property
    def rest_user_password(self):
        """
        Gets the rest_user_password of this FppServer.
        FPP REST User Password


        :return: The rest_user_password of this FppServer.
        :rtype: str
        """
        return self._rest_user_password

    @rest_user_password.setter
    def rest_user_password(self, rest_user_password):
        """
        Sets the rest_user_password of this FppServer.
        FPP REST User Password


        :param rest_user_password: The rest_user_password of this FppServer.
        :type: str
        """
        self._rest_user_password = rest_user_password

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this FppServer.
        The time the the FPP server was created. An RFC3339 formatted datetime string


        :return: The time_created of this FppServer.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this FppServer.
        The time the the FPP server was created. An RFC3339 formatted datetime string


        :param time_created: The time_created of this FppServer.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this FppServer.
        The time the FPP server was updated. An RFC3339 formatted datetime string


        :return: The time_updated of this FppServer.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this FppServer.
        The time the FPP server was updated. An RFC3339 formatted datetime string


        :param time_updated: The time_updated of this FppServer.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this FppServer.
        The current state of the FPP server.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"


        :return: The lifecycle_state of this FppServer.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this FppServer.
        The current state of the FPP server.


        :param lifecycle_state: The lifecycle_state of this FppServer.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            raise ValueError(
                f"Invalid value for `lifecycle_state`, must be None or one of {allowed_values}"
            )
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this FppServer.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :return: The lifecycle_details of this FppServer.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this FppServer.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :param lifecycle_details: The lifecycle_details of this FppServer.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def freeform_tags(self):
        """
        **[Required]** Gets the freeform_tags of this FppServer.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this FppServer.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this FppServer.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this FppServer.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        **[Required]** Gets the defined_tags of this FppServer.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this FppServer.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this FppServer.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this FppServer.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this FppServer.
        System tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this FppServer.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this FppServer.
        System tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this FppServer.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VulnerabilityScan(object):
    """
    A VulnerabilityScan is a description of a VulnerabilityScan.

    To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to
    an administrator. If you're an administrator who needs to write policies to give users access, see
    `Getting Started with Policies`__.

    __ https://docs.oracle.com/iaas/Content/Identity/policiesgs/get-started-with-policies.htm
    """

    #: A constant which can be used with the vulnerability_scan_type property of a VulnerabilityScan.
    #: This constant has a value of "CVE"
    VULNERABILITY_SCAN_TYPE_CVE = "CVE"

    #: A constant which can be used with the vulnerability_scan_type property of a VulnerabilityScan.
    #: This constant has a value of "PATCH"
    VULNERABILITY_SCAN_TYPE_PATCH = "PATCH"

    #: A constant which can be used with the vulnerability_scan_type property of a VulnerabilityScan.
    #: This constant has a value of "IMAGE_PATCH"
    VULNERABILITY_SCAN_TYPE_IMAGE_PATCH = "IMAGE_PATCH"

    #: A constant which can be used with the vulnerability_scan_status property of a VulnerabilityScan.
    #: This constant has a value of "COMPLETED"
    VULNERABILITY_SCAN_STATUS_COMPLETED = "COMPLETED"

    #: A constant which can be used with the vulnerability_scan_status property of a VulnerabilityScan.
    #: This constant has a value of "ERROR"
    VULNERABILITY_SCAN_STATUS_ERROR = "ERROR"

    #: A constant which can be used with the vulnerability_scan_status property of a VulnerabilityScan.
    #: This constant has a value of "RUNNING"
    VULNERABILITY_SCAN_STATUS_RUNNING = "RUNNING"

    #: A constant which can be used with the vulnerability_scan_status property of a VulnerabilityScan.
    #: This constant has a value of "ABORTED"
    VULNERABILITY_SCAN_STATUS_ABORTED = "ABORTED"

    #: A constant which can be used with the lifecycle_state property of a VulnerabilityScan.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a VulnerabilityScan.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a VulnerabilityScan.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a VulnerabilityScan.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a VulnerabilityScan.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a VulnerabilityScan.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new VulnerabilityScan object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this VulnerabilityScan.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this VulnerabilityScan.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this VulnerabilityScan.
        :type compartment_id: str

        :param vulnerability_scan_type:
            The value to assign to the vulnerability_scan_type property of this VulnerabilityScan.
            Allowed values for this property are: "CVE", "PATCH", "IMAGE_PATCH", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type vulnerability_scan_type: str

        :param vulnerability_scan_status:
            The value to assign to the vulnerability_scan_status property of this VulnerabilityScan.
            Allowed values for this property are: "COMPLETED", "ERROR", "RUNNING", "ABORTED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type vulnerability_scan_status: str

        :param vulnerability_scan_message:
            The value to assign to the vulnerability_scan_message property of this VulnerabilityScan.
        :type vulnerability_scan_message: str

        :param time_created:
            The value to assign to the time_created property of this VulnerabilityScan.
        :type time_created: datetime

        :param time_ended:
            The value to assign to the time_ended property of this VulnerabilityScan.
        :type time_ended: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this VulnerabilityScan.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this VulnerabilityScan.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this VulnerabilityScan.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this VulnerabilityScan.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'compartment_id': 'str',
            'vulnerability_scan_type': 'str',
            'vulnerability_scan_status': 'str',
            'vulnerability_scan_message': 'str',
            'time_created': 'datetime',
            'time_ended': 'datetime',
            'lifecycle_state': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }
        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'vulnerability_scan_type': 'vulnerabilityScanType',
            'vulnerability_scan_status': 'vulnerabilityScanStatus',
            'vulnerability_scan_message': 'vulnerabilityScanMessage',
            'time_created': 'timeCreated',
            'time_ended': 'timeEnded',
            'lifecycle_state': 'lifecycleState',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }
        self._id = None
        self._display_name = None
        self._compartment_id = None
        self._vulnerability_scan_type = None
        self._vulnerability_scan_status = None
        self._vulnerability_scan_message = None
        self._time_created = None
        self._time_ended = None
        self._lifecycle_state = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this VulnerabilityScan.
        The `OCID`__ of the VulnerabilityScan.

        __ https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this VulnerabilityScan.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this VulnerabilityScan.
        The `OCID`__ of the VulnerabilityScan.

        __ https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this VulnerabilityScan.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        Gets the display_name of this VulnerabilityScan.
        A user-friendly name. It does not have to be unique, and it is changeable.


        :return: The display_name of this VulnerabilityScan.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this VulnerabilityScan.
        A user-friendly name. It does not have to be unique, and it is changeable.


        :param display_name: The display_name of this VulnerabilityScan.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this VulnerabilityScan.
        The `OCID`__ of the compartment.

        __ https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this VulnerabilityScan.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this VulnerabilityScan.
        The `OCID`__ of the compartment.

        __ https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this VulnerabilityScan.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def vulnerability_scan_type(self):
        """
        **[Required]** Gets the vulnerability_scan_type of this VulnerabilityScan.
        Scan type is CVE, PATCH or IMAGE_PATCH

        Allowed values for this property are: "CVE", "PATCH", "IMAGE_PATCH", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The vulnerability_scan_type of this VulnerabilityScan.
        :rtype: str
        """
        return self._vulnerability_scan_type

    @vulnerability_scan_type.setter
    def vulnerability_scan_type(self, vulnerability_scan_type):
        """
        Sets the vulnerability_scan_type of this VulnerabilityScan.
        Scan type is CVE, PATCH or IMAGE_PATCH


        :param vulnerability_scan_type: The vulnerability_scan_type of this VulnerabilityScan.
        :type: str
        """
        allowed_values = ["CVE", "PATCH", "IMAGE_PATCH"]
        if not value_allowed_none_or_none_sentinel(vulnerability_scan_type, allowed_values):
            vulnerability_scan_type = 'UNKNOWN_ENUM_VALUE'
        self._vulnerability_scan_type = vulnerability_scan_type

    @property
    def vulnerability_scan_status(self):
        """
        **[Required]** Gets the vulnerability_scan_status of this VulnerabilityScan.
        The status of the vulnerability scan.

        Allowed values for this property are: "COMPLETED", "ERROR", "RUNNING", "ABORTED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The vulnerability_scan_status of this VulnerabilityScan.
        :rtype: str
        """
        return self._vulnerability_scan_status

    @vulnerability_scan_status.setter
    def vulnerability_scan_status(self, vulnerability_scan_status):
        """
        Sets the vulnerability_scan_status of this VulnerabilityScan.
        The status of the vulnerability scan.


        :param vulnerability_scan_status: The vulnerability_scan_status of this VulnerabilityScan.
        :type: str
        """
        allowed_values = ["COMPLETED", "ERROR", "RUNNING", "ABORTED"]
        if not value_allowed_none_or_none_sentinel(vulnerability_scan_status, allowed_values):
            vulnerability_scan_status = 'UNKNOWN_ENUM_VALUE'
        self._vulnerability_scan_status = vulnerability_scan_status

    @property
    def vulnerability_scan_message(self):
        """
        **[Required]** Gets the vulnerability_scan_message of this VulnerabilityScan.
        The message of the vulnerability scan status.


        :return: The vulnerability_scan_message of this VulnerabilityScan.
        :rtype: str
        """
        return self._vulnerability_scan_message

    @vulnerability_scan_message.setter
    def vulnerability_scan_message(self, vulnerability_scan_message):
        """
        Sets the vulnerability_scan_message of this VulnerabilityScan.
        The message of the vulnerability scan status.


        :param vulnerability_scan_message: The vulnerability_scan_message of this VulnerabilityScan.
        :type: str
        """
        self._vulnerability_scan_message = vulnerability_scan_message

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this VulnerabilityScan.
        The date and time the VulnerabilityScan was created, in the format defined by `RFC 3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this VulnerabilityScan.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this VulnerabilityScan.
        The date and time the VulnerabilityScan was created, in the format defined by `RFC 3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this VulnerabilityScan.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_ended(self):
        """
        **[Required]** Gets the time_ended of this VulnerabilityScan.
        The date and time the VulnerabilityScan was updated, in the format defined by `RFC 3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_ended of this VulnerabilityScan.
        :rtype: datetime
        """
        return self._time_ended

    @time_ended.setter
    def time_ended(self, time_ended):
        """
        Sets the time_ended of this VulnerabilityScan.
        The date and time the VulnerabilityScan was updated, in the format defined by `RFC 3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_ended: The time_ended of this VulnerabilityScan.
        :type: datetime
        """
        self._time_ended = time_ended

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this VulnerabilityScan.
        The current state of the VulnerabilityScan.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this VulnerabilityScan.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this VulnerabilityScan.
        The current state of the VulnerabilityScan.


        :param lifecycle_state: The lifecycle_state of this VulnerabilityScan.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this VulnerabilityScan.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this VulnerabilityScan.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this VulnerabilityScan.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this VulnerabilityScan.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this VulnerabilityScan.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this VulnerabilityScan.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this VulnerabilityScan.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this VulnerabilityScan.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this VulnerabilityScan.
        System tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this VulnerabilityScan.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this VulnerabilityScan.
        System tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this VulnerabilityScan.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
